==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/VlanMatchConditionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.VlanMatchConditionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The vlan match conditions that need to be matched.
 * @property innerVlans List of inner vlans that need to be matched.
 * @property vlanGroupNames List of vlan group names that need to be matched.
 * @property vlans List of vlans that need to be matched.
 */
public data class VlanMatchConditionArgs(
    public val innerVlans: Output<List<String>>? = null,
    public val vlanGroupNames: Output<List<String>>? = null,
    public val vlans: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.VlanMatchConditionArgs> {
    override fun toJava(): com.pulumi.azurenative.managednetworkfabric.inputs.VlanMatchConditionArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.VlanMatchConditionArgs.builder()
            .innerVlans(innerVlans?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .vlanGroupNames(vlanGroupNames?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .vlans(vlans?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [VlanMatchConditionArgs].
 */
@PulumiTagMarker
public class VlanMatchConditionArgsBuilder internal constructor() {
    private var innerVlans: Output<List<String>>? = null

    private var vlanGroupNames: Output<List<String>>? = null

    private var vlans: Output<List<String>>? = null

    /**
     * @param value List of inner vlans that need to be matched.
     */
    @JvmName("ubaakbvaymixnqgy")
    public suspend fun innerVlans(`value`: Output<List<String>>) {
        this.innerVlans = value
    }

    @JvmName("mtupahsqmahobmms")
    public suspend fun innerVlans(vararg values: Output<String>) {
        this.innerVlans = Output.all(values.asList())
    }

    /**
     * @param values List of inner vlans that need to be matched.
     */
    @JvmName("tfybmgytskaepvuw")
    public suspend fun innerVlans(values: List<Output<String>>) {
        this.innerVlans = Output.all(values)
    }

    /**
     * @param value List of vlan group names that need to be matched.
     */
    @JvmName("gabhgkeprgwopsxf")
    public suspend fun vlanGroupNames(`value`: Output<List<String>>) {
        this.vlanGroupNames = value
    }

    @JvmName("usstsyjwbusnfeqf")
    public suspend fun vlanGroupNames(vararg values: Output<String>) {
        this.vlanGroupNames = Output.all(values.asList())
    }

    /**
     * @param values List of vlan group names that need to be matched.
     */
    @JvmName("cryhbmgidtjmwnwi")
    public suspend fun vlanGroupNames(values: List<Output<String>>) {
        this.vlanGroupNames = Output.all(values)
    }

    /**
     * @param value List of vlans that need to be matched.
     */
    @JvmName("sndncnbcifcptlms")
    public suspend fun vlans(`value`: Output<List<String>>) {
        this.vlans = value
    }

    @JvmName("kwemtbddwomcywau")
    public suspend fun vlans(vararg values: Output<String>) {
        this.vlans = Output.all(values.asList())
    }

    /**
     * @param values List of vlans that need to be matched.
     */
    @JvmName("lpbecnxhtdvjmyaq")
    public suspend fun vlans(values: List<Output<String>>) {
        this.vlans = Output.all(values)
    }

    /**
     * @param value List of inner vlans that need to be matched.
     */
    @JvmName("ggjtsmdlmwdqnynp")
    public suspend fun innerVlans(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.innerVlans = mapped
    }

    /**
     * @param values List of inner vlans that need to be matched.
     */
    @JvmName("slkmtrhorgpjrtux")
    public suspend fun innerVlans(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.innerVlans = mapped
    }

    /**
     * @param value List of vlan group names that need to be matched.
     */
    @JvmName("rexajbcswrixnhqj")
    public suspend fun vlanGroupNames(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vlanGroupNames = mapped
    }

    /**
     * @param values List of vlan group names that need to be matched.
     */
    @JvmName("shhoaeirurqtesve")
    public suspend fun vlanGroupNames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vlanGroupNames = mapped
    }

    /**
     * @param value List of vlans that need to be matched.
     */
    @JvmName("nktpgabgygvmymgq")
    public suspend fun vlans(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vlans = mapped
    }

    /**
     * @param values List of vlans that need to be matched.
     */
    @JvmName("ylxhbnnppjflwymv")
    public suspend fun vlans(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vlans = mapped
    }

    internal fun build(): VlanMatchConditionArgs = VlanMatchConditionArgs(
        innerVlans = innerVlans,
        vlanGroupNames = vlanGroupNames,
        vlans = vlans,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/managednetworkfabric/kotlin/inputs/VlanMatchConditionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetworkfabric.kotlin.inputs

import com.pulumi.azurenative.managednetworkfabric.inputs.VlanMatchConditionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The vlan match conditions that need to be matched.
 * @property innerVlans List of inner vlans that need to be matched.
 * @property vlanGroupNames List of vlan group names that need to be matched.
 * @property vlans List of vlans that need to be matched.
 */
public data class VlanMatchConditionArgs(
    public val innerVlans: Output<List<String>>? = null,
    public val vlanGroupNames: Output<List<String>>? = null,
    public val vlans: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.managednetworkfabric.inputs.VlanMatchConditionArgs> {
    override fun toJava(): com.pulumi.azurenative.managednetworkfabric.inputs.VlanMatchConditionArgs =
        com.pulumi.azurenative.managednetworkfabric.inputs.VlanMatchConditionArgs.builder()
            .innerVlans(innerVlans?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .vlanGroupNames(vlanGroupNames?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .vlans(vlans?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [VlanMatchConditionArgs].
 */
@PulumiTagMarker
public class VlanMatchConditionArgsBuilder internal constructor() {
    private var innerVlans: Output<List<String>>? = null

    private var vlanGroupNames: Output<List<String>>? = null

    private var vlans: Output<List<String>>? = null

    /**
     * @param value List of inner vlans that need to be matched.
     */
    @JvmName("fhjwplvxhbsljvpx")
    public suspend fun innerVlans(`value`: Output<List<String>>) {
        this.innerVlans = value
    }

    @JvmName("apubfgjburuloyfr")
    public suspend fun innerVlans(vararg values: Output<String>) {
        this.innerVlans = Output.all(values.asList())
    }

    /**
     * @param values List of inner vlans that need to be matched.
     */
    @JvmName("tgagttexrjcdffbu")
    public suspend fun innerVlans(values: List<Output<String>>) {
        this.innerVlans = Output.all(values)
    }

    /**
     * @param value List of vlan group names that need to be matched.
     */
    @JvmName("imryluhartowblrg")
    public suspend fun vlanGroupNames(`value`: Output<List<String>>) {
        this.vlanGroupNames = value
    }

    @JvmName("frqupiegtarruont")
    public suspend fun vlanGroupNames(vararg values: Output<String>) {
        this.vlanGroupNames = Output.all(values.asList())
    }

    /**
     * @param values List of vlan group names that need to be matched.
     */
    @JvmName("dksvrgbpyoxdixro")
    public suspend fun vlanGroupNames(values: List<Output<String>>) {
        this.vlanGroupNames = Output.all(values)
    }

    /**
     * @param value List of vlans that need to be matched.
     */
    @JvmName("usoiaiotdypesnlv")
    public suspend fun vlans(`value`: Output<List<String>>) {
        this.vlans = value
    }

    @JvmName("ekxlgqmfwldjkymx")
    public suspend fun vlans(vararg values: Output<String>) {
        this.vlans = Output.all(values.asList())
    }

    /**
     * @param values List of vlans that need to be matched.
     */
    @JvmName("xdsomlvlpkycifkv")
    public suspend fun vlans(values: List<Output<String>>) {
        this.vlans = Output.all(values)
    }

    /**
     * @param value List of inner vlans that need to be matched.
     */
    @JvmName("vptsckvaviacrbrf")
    public suspend fun innerVlans(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.innerVlans = mapped
    }

    /**
     * @param values List of inner vlans that need to be matched.
     */
    @JvmName("ybmdfymybixhkotw")
    public suspend fun innerVlans(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.innerVlans = mapped
    }

    /**
     * @param value List of vlan group names that need to be matched.
     */
    @JvmName("lvnauuwnlmqkiann")
    public suspend fun vlanGroupNames(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vlanGroupNames = mapped
    }

    /**
     * @param values List of vlan group names that need to be matched.
     */
    @JvmName("qtcdbetojbyxxlnb")
    public suspend fun vlanGroupNames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vlanGroupNames = mapped
    }

    /**
     * @param value List of vlans that need to be matched.
     */
    @JvmName("qgbbebegkhkhbtpe")
    public suspend fun vlans(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vlans = mapped
    }

    /**
     * @param values List of vlans that need to be matched.
     */
    @JvmName("fnephqwtydfmwwcr")
    public suspend fun vlans(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vlans = mapped
    }

    internal fun build(): VlanMatchConditionArgs = VlanMatchConditionArgs(
        innerVlans = innerVlans,
        vlanGroupNames = vlanGroupNames,
        vlans = vlans,
    )
}
